# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-07 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0004_auto_20171101_1816")]

    operations = [
        migrations.AlterField(
            model_name="myuser",
            name="customer_category",
            field=models.CharField(
                blank=True,
                choices=[
                    ("ACTIVE_PARTNER", "active partner"),
                    ("BI_FOLDING_DOOR_SPECIALIST", "bi-folding-door specialist"),
                    ("DEALER", "dealer"),
                    ("ARCHITECT_PLANNER", "architect/planner"),
                    ("HOUSING_SOCIETY", "housing society"),
                    ("PRIVATE_CUSTOMER", "private customer"),
                    ("OTHERS", "others"),
                ],
                max_length=200,
                null=True,
                verbose_name="customer category",
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="customer_name",
            field=models.CharField(
                blank=True, max_length=200, null=True, verbose_name="customer name"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=30, null=True, verbose_name="first name"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="last_name",
            field=models.CharField(
                blank=True, max_length=150, null=True, verbose_name="last name"
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="title",
            field=models.CharField(
                blank=True, max_length=20, null=True, verbose_name="title"
            ),
        ),
    ]
