# Generated by Django 2.0.1 on 2018-02-08 09:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("example", "0007_myuser_access_token")]

    operations = [
        migrations.RemoveField(model_name="myuser", name="avatar_attachment_id"),
        migrations.RemoveField(model_name="myuser", name="company_logo_attachment_id"),
        migrations.AlterField(
            model_name="myuser",
            name="customer_category",
            field=models.CharField(
                blank=True,
                choices=[
                    ("QUALITY_PARTNER", "quality partner"),
                    ("DEALER", "dealer"),
                    ("ARCHITECT_PLANNER", "architect/planner"),
                    ("HOUSING_SOCIETY", "housing society"),
                    ("PRIVATE_CUSTOMER", "private customer"),
                    ("OTHERS", "others"),
                    ("INTERNAL", "internal"),
                ],
                max_length=200,
                null=True,
                verbose_name="customer category",
            ),
        ),
        migrations.AlterField(
            model_name="myuser",
            name="customer_no",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="customer no"
            ),
        ),
    ]
